==> pkg_trackinst-1.0.tar.gz: pkg_trackinst-1.0/PkgTrackInst/main.py <==
#!/usr/bin/env python
#
# pkg_trackinst.py - Tracks installation log and generates package.
#
# ----------------------------------------------------------------------------
# "THE BEER-WARE LICENSE" (Revision 42, (c) Poul-Henning Kamp):
# Hye-Shik Chang <perky@FreeBSD.org> wrote this file.  As long as you retain
# this notice you can do whatever you want with this stuff. If we meet some
# day, and you think this stuff is worth it, you can buy me a beer in return.
#
# Hye-Shik Chang
# ----------------------------------------------------------------------------
# $Id: main.py 494 2005-05-05 15:23:56Z perky $

__pychecker__ = 'no-argsused no-isliteral'

from PkgTrackInst.cmd_support import *
import os, sys
import tempfile

options = None

def parse_options():
    from optparse import OptionParser
    usage = "usage: %prog [options] [install command]"
    parser = OptionParser(usage=usage)
    parser.add_option('-v', '--version', dest='show_version', default=False,
                      action='store_true', help="show version and exit")
    parser.add_option('-b', '--batch', dest='interactive', default=True,
                      action='store_false',
                      help="don't get any interactive inputs")
    parser.add_option('-p', '--prefix', dest='prefix', default='/usr/local',
                      help='prefix where package is being installed',
                      metavar='DIR')
    parser.add_option('-d', '--pkgdb', dest='pkgdb', default='/var/db/pkg',
                      help='package database directory where keeps ports info',
                      metavar='DIR')
    parser.add_option('-n', '--no-create-package', dest='create_package',
                      default=True, action='store_false',
                      help="don't create a binary package after install")
    parser.add_option('-m', '--message', dest='message',
                      help="text file to show after installations (package)",
                      default=False, metavar='FILE')
    parser.add_option('', '--install-script', dest='install_script',
                      help="script file to run after installations (package)",
                      default=None, metavar='FILE')
    parser.add_option('', '--deinstall-script', dest='deinstall_script',
                      help="script file to run after deinstallations (package)",
                      default=None, metavar='FILE')
    opts, args = parser.parse_args()
    opts.command = args
    return opts

INSTALLCMD_HINTS = (
    # file exists   command
    ('test-trackinst', './test-trackinst'),
    ('Makefile', 'make install'),
    ('makefile', 'make install'),
    ('setup.py', 'python setup.py install'),
    ('configure', './configure && make && make install'),
)
def run_install():
    if not options.command:
        # guess a command.
        for chkfile, cmd in INSTALLCMD_HINTS:
            if os.path.exists(chkfile):
                command = cmd
                break
        else:
            errx("Can't determine command to invoke installation.")
    elif 'sudo' in options.command:
        errx("`sudo' command isn't compatible with %s." % sys.argv[0])
    else:
        command = ' '.join(options.command)

    echo_msg('Installing')
    ilog = tempfile.NamedTemporaryFile()
    envs = 'LD_PRELOAD=%s INSTALLWATCHFILE=%s' % (INSTALLWATCH_PATH, ilog.name)
    status = os.system(' '.join((envs, command)))
    if status:
        errx("`%s' is failed with status code %d." % (command, status))
    return open(ilog.name)

def parse_log(logf):
    from PkgTrackInst.InstallSession import InstallSession
    inst = InstallSession()
    for line in logf:
        inst.feed(line[:-1])

def main():
    global options

    import PkgTrackInst
    PkgTrackInst.options = options = parse_options()

    if options.show_version:
        from PkgTrackInst.cmd_support import __banner__
        print __banner__ % 'pkg_trackinst'
        raise SystemExit

    # Get input about basic informations on pkgdb entry.
    from PkgTrackInst.PkgDbInfoForm import get_pkgdb_info
    dbinfo = get_pkgdb_info()

    # Create pkgdb writer instance
    from PkgTrackInst.PkgDbWriter import PkgDbWriter
    writer = PkgDbWriter(dbinfo)

    # Run install command with libinstallwatch preloaded.
    logf = run_install()

    # Parse install log and build directory architecture.
    parse_log(logf)

    # Delete known temporary/build directories from the track list.
    from PkgTrackInst.Trackers import TrackRoot
    for dpfx in IGNORE_PATHS + [os.path.realpath(os.getcwd())]:
        del TrackRoot[dpfx]

    have_entry = []
    def found_entry(ent):
        if ent.created:
            have_entry.append(True)
    TrackRoot.walk(found_entry)
    if not have_entry:
        errx('No file is installed.')

    # Mark mtree directories as not created by the problem.
    from PkgTrackInst.Trackers import MTreeMarker
    MTreeMarker(options.prefix, MTREE_LOCAL).mark()

    # Write into pkgdb
    writer.write()

    # Create a binary package
    if options.create_package:
        writer.create_package()

if __name__ == '__main__':
    main()

==> pkg_trackinst-1.1.tar.gz: pkg_trackinst-1.1/PkgTrackInst/main.py <==
#!/usr/bin/env python
#
# pkg_trackinst.py - Tracks installation log and generates package.
#
# ----------------------------------------------------------------------------
# "THE BEER-WARE LICENSE" (Revision 42, (c) Poul-Henning Kamp):
# Hye-Shik Chang <perky@FreeBSD.org> wrote this file.  As long as you retain
# this notice you can do whatever you want with this stuff. If we meet some
# day, and you think this stuff is worth it, you can buy me a beer in return.
#
# Hye-Shik Chang
# ----------------------------------------------------------------------------
# $Id: main.py 499 2005-05-08 02:28:29Z perky $

__pychecker__ = 'no-argsused no-isliteral'

from PkgTrackInst.cmd_support import *
import os, sys
import tempfile

options = None

def parse_options():
    from optparse import OptionParser
    usage = "usage: %prog [options] [install command]"
    parser = OptionParser(usage=usage)
    parser.add_option('-v', '--version', dest='show_version', default=False,
                      action='store_true', help="show version and exit")
    parser.add_option('-b', '--batch', dest='interactive', default=True,
                      action='store_false',
                      help="don't get any interactive inputs")
    parser.add_option('-p', '--prefix', dest='prefix', default='/usr/local',
                      help='prefix where package is being installed',
                      metavar='DIR')
    parser.add_option('-d', '--pkgdb', dest='pkgdb', default='/var/db/pkg',
                      help='package database directory where keeps ports info',
                      metavar='DIR')
    parser.add_option('-n', '--no-create-package', dest='create_package',
                      default=True, action='store_false',
                      help="don't create a binary package after install")
    parser.add_option('-m', '--message', dest='message',
                      help="text file to show after installations (package)",
                      default=False, metavar='FILE')
    parser.add_option('', '--install-script', dest='install_script',
                      help="script file to run after installations (package)",
                      default=None, metavar='FILE')
    parser.add_option('', '--deinstall-script', dest='deinstall_script',
                      help="script file to run after deinstallations (package)",
                      default=None, metavar='FILE')
    opts, args = parser.parse_args()
    opts.command = args
    return opts

INSTALLCMD_HINTS = (
    # file exists   command
    ('test-trackinst', './test-trackinst'),
    ('Makefile', 'make install'),
    ('makefile', 'make install'),
    ('setup.py', 'python setup.py install'),
    ('configure', './configure && make && make install'),
)
def run_install():
    if not options.command:
        # guess a command.
        for chkfile, cmd in INSTALLCMD_HINTS:
            if os.path.exists(chkfile):
                command = cmd
                break
        else:
            errx("Can't determine command to invoke installation.")
    elif 'sudo' in options.command:
        errx("`sudo' command isn't compatible with %s." % sys.argv[0])
    else:
        command = ' '.join(options.command)

    echo_msg('Installing')
    ilog = tempfile.NamedTemporaryFile()
    envs = 'LD_PRELOAD=%s INSTHOOK_LOGFILE=%s' % (INSTHOOK_PATH, ilog.name)
    status = os.system(' '.join((envs, command)))
    if status:
        errx("`%s' is failed with status code %d." % (command, status))
    return open(ilog.name)

def parse_log(logf):
    from PkgTrackInst.InstallSession import InstallSession
    inst = InstallSession()
    for line in logf:
        inst.feed(line[:-1])

def main():
    global options

    import PkgTrackInst
    PkgTrackInst.options = options = parse_options()

    if options.show_version:
        from PkgTrackInst.cmd_support import __banner__
        print __banner__ % 'pkg_trackinst'
        raise SystemExit

    # Get input about basic informations on pkgdb entry.
    from PkgTrackInst.PkgDbInfoForm import get_pkgdb_info
    dbinfo = get_pkgdb_info()

    # Create pkgdb writer instance
    from PkgTrackInst.PkgDbWriter import PkgDbWriter
    writer = PkgDbWriter(dbinfo)

    # Run install command with libinstallwatch preloaded.
    logf = run_install()

    # Parse install log and build directory architecture.
    parse_log(logf)

    # Delete known temporary/build directories from the track list.
    from PkgTrackInst.Trackers import TrackRoot
    for dpfx in IGNORE_PATHS + [os.path.realpath(os.getcwd())]:
        del TrackRoot[dpfx]

    have_entry = []
    def found_entry(ent):
        if ent.created:
            have_entry.append(True)
    TrackRoot.walk(found_entry)
    if not have_entry:
        errx('No file is installed.')

    # Mark mtree directories as not created by the problem.
    from PkgTrackInst.Trackers import MTreeMarker
    MTreeMarker(options.prefix, MTREE_LOCAL).mark()

    # Write into pkgdb
    writer.write()

    # Create a binary package
    if options.create_package:
        writer.create_package()

if __name__ == '__main__':
    main()
